==> eo-2.6.zip: eo/public.lang.php <==
<?php
# -- BEGIN LICENSE BLOCK ---------------------------------------
#
# This file is part of Dotclear 2.
#
# Copyright (c) 2003-2013 Olivier Meunier & Association Dotclear
# Licensed under the GPL version 2.0 license.
# See LICENSE file or
# http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
#
# -- END LICENSE BLOCK -----------------------------------------#
#
#
#		  DOT NOT MODIFY THIS FILE !




$GLOBALS['__l10n']['To content'] = 'Al kontento';
$GLOBALS['__l10n']['To menu'] = 'Al menuo';
$GLOBALS['__l10n']['To search'] = 'Al serĉilo';
$GLOBALS['__l10n']['By'] = 'Far';
$GLOBALS['__l10n']['by'] = 'far';
$GLOBALS['__l10n']['on'] = 'je la';
$GLOBALS['__l10n']['On'] = 'Je la';
$GLOBALS['__l10n']['Continue reading'] = 'Legi plu';
$GLOBALS['__l10n']['no comment'] = 'neniu komento';
$GLOBALS['__l10n']['one comment'] = 'neniu komento';
$GLOBALS['__l10n']['%d comments'] = '%d komentoj';
$GLOBALS['__l10n']['no trackback'] = 'neniu retroligo';
$GLOBALS['__l10n']['one trackback'] = 'unu retroligo';
$GLOBALS['__l10n']['%d trackbacks'] = '%d retroligoj';
$GLOBALS['__l10n']['no attachment'] = 'neniu aldonaĵo';
$GLOBALS['__l10n']['one attachment'] = 'unu aldonaĵo';
$GLOBALS['__l10n']['%d attachments'] = '%d aldonaĵoj';
$GLOBALS['__l10n']['previous entries'] = 'malantaŭaj biletoj';
$GLOBALS['__l10n']['page'] = 'paĝo';
$GLOBALS['__l10n']['of'] = 'de';
$GLOBALS['__l10n']['next entries'] = 'antaŭaj biletoj';
$GLOBALS['__l10n']['Search'] = 'Serĉi';
$GLOBALS['__l10n']['Your search for <em>%1$s</em> returned no result.'] = 'Via serĉo pri <em>%1$s</em> trovis neniun rezulton.';
$GLOBALS['__l10n']['Your search for <em>%1$s</em> returned <strong>%2$s</strong> result.'] = 'Via serĉo pri <em>%1$s</em> trovis <strong>%2$s</strong> rezultojn.';
$GLOBALS['__l10n']['Your search for <em>%1$s</em> returned <strong>%2$s</strong> results.'] = 'Via serĉo pri <em>%1$s</em> trovis <strong>%2$s</strong> rezultojn.';
$GLOBALS['__l10n']['Home'] = 'Hejmpaĝo';
$GLOBALS['__l10n']['All keywords'] = 'Ĉiuj ŝlosilvortoj';
$GLOBALS['__l10n']['Best of me'] = '';
$GLOBALS['__l10n']['Languages'] = 'Lingvoj';
$GLOBALS['__l10n']['Categories'] = 'Kategorioj';
$GLOBALS['__l10n']['Subcategories'] = 'Subkategorioj';
$GLOBALS['__l10n']['Archives'] = 'Arkivoj';
$GLOBALS['__l10n']['Links'] = 'Ligoj';
$GLOBALS['__l10n']['Subscribe'] = 'Aboni';
$GLOBALS['__l10n']['Entries feed'] = 'Ĉeno de la biletoj';
$GLOBALS['__l10n']['Comments feed'] = 'Ĉeno de la komentoj';
$GLOBALS['__l10n']['This blog\'s comments Atom feed'] = 'La Atom-a ĉeno de tiu blogo komentoj';
$GLOBALS['__l10n']['This category\'s entries Atom feed'] = '';
$GLOBALS['__l10n']['This category\'s comments Atom feed'] = '';
$GLOBALS['__l10n']['This post\'s comments feed'] = '';
$GLOBALS['__l10n']['This post\'s comments Atom feed'] = '';
$GLOBALS['__l10n']['Attachments'] = 'Aldonaĵoj';
$GLOBALS['__l10n']['Permalink'] = 'Permanenta ligilo';
$GLOBALS['__l10n']['Comments'] = 'Komentoj';
$GLOBALS['__l10n']['Your comment'] = 'Via komento';
$GLOBALS['__l10n']['Your comment has been published.'] = 'Via komento estis publikigita';
$GLOBALS['__l10n']['Your comment has been submitted and will be reviewed for publication.'] = 'Via komento estis sendita kaj estos kontrolita antaŭ publikigado.';
$GLOBALS['__l10n']['Add a comment'] = 'Aldoni komenton';
$GLOBALS['__l10n']['Name or nickname'] = 'Nomo';
$GLOBALS['__l10n']['Email address'] = 'Retpoŝtadreso';
$GLOBALS['__l10n']['Website'] = 'Retejo';
$GLOBALS['__l10n']['optional'] = 'opcia';
$GLOBALS['__l10n']['Comment'] = 'Komento';
$GLOBALS['__l10n']['Comments can be formatted using a simple wiki syntax.'] = '';
$GLOBALS['__l10n']['HTML code is displayed as text and web addresses are automatically converted.'] = '';
$GLOBALS['__l10n']['Remember me on this blog'] = 'Memoru min en tiu blogo';
$GLOBALS['__l10n']['preview'] = 'previdi';
$GLOBALS['__l10n']['send'] = 'sendi';
$GLOBALS['__l10n']['They posted on the same topic'] = '';
$GLOBALS['__l10n']['Trackback URL'] = '';
$GLOBALS['__l10n']['You must provide an author name'] = '';
$GLOBALS['__l10n']['You must provide a comment'] = '';
$GLOBALS['__l10n']['Email address is not valid'] = '';
$GLOBALS['__l10n']['Document not found'] = 'Dokumento ne trovebla';
$GLOBALS['__l10n']['The document you are looking for does not exist.'] = 'La dokumento kiun vi serĉas ne ekzistas.';
$GLOBALS['__l10n']['Powered by %s'] = '';
$GLOBALS['__l10n']['Subscribe to'] = '';
$GLOBALS['__l10n']['What is an RSS feed?'] = '';
$GLOBALS['__l10n']['RSS feed is a free blog summary. It provides content (either posts or comments) or summaries of content, together with links to the full versions, and other metadata. The last published items may then be read by your favorite RSS <a href="http://en.wikipedia.org/wiki/Aggregator">aggregator</a>.'] = '';
$GLOBALS['__l10n']['Simply copy the following URL into your aggregator:'] = '';
$GLOBALS['__l10n']['Password needed'] = 'Pasvorto necesa';
$GLOBALS['__l10n']['You must give a password to access this area.'] = 'Vi devas doni pasvorton por vidi tiun paĝon.';
$GLOBALS['__l10n']['Password:'] = 'Pasvorto:';
$GLOBALS['__l10n']['You must provide a valid email address.'] = 'Vi devas doni korektan retpoŝtadreson.';
$GLOBALS['__l10n']['Read'] = 'Legi';

==> eo-2.10.zip: eo/public.lang.php <==
<?php
# -- BEGIN LICENSE BLOCK ---------------------------------------
#
# This file is part of Dotclear 2.
#
# Copyright (c) 2003-2013 Olivier Meunier & Association Dotclear
# Licensed under the GPL version 2.0 license.
# See LICENSE file or
# http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
#
# -- END LICENSE BLOCK -----------------------------------------#
#
#
#		  DOT NOT MODIFY THIS FILE !




$GLOBALS['__l10n']['To content'] = 'Al kontento';
$GLOBALS['__l10n']['To menu'] = 'Al menuo';
$GLOBALS['__l10n']['To search'] = 'Al serĉilo';
$GLOBALS['__l10n']['By'] = 'Far';
$GLOBALS['__l10n']['by'] = 'far';
$GLOBALS['__l10n']['on'] = 'je la';
$GLOBALS['__l10n']['On'] = 'Je la';
$GLOBALS['__l10n']['Continue reading'] = 'Legi plu';
$GLOBALS['__l10n']['no comments'] = 'neniu komento';
$GLOBALS['__l10n']['one comment'] = 'neniu komento';
$GLOBALS['__l10n']['%d comments'] = '%d komentoj';
$GLOBALS['__l10n']['no trackbacks'] = 'neniu retroligo';
$GLOBALS['__l10n']['one trackback'] = 'unu retroligo';
$GLOBALS['__l10n']['%d trackbacks'] = '%d retroligoj';
$GLOBALS['__l10n']['no attachments'] = 'neniu aldonaĵo';
$GLOBALS['__l10n']['one attachment'] = 'unu aldonaĵo';
$GLOBALS['__l10n']['%d attachments'] = '%d aldonaĵoj';
$GLOBALS['__l10n']['previous entries'] = 'malantaŭaj biletoj';
$GLOBALS['__l10n']['page'] = 'paĝo';
$GLOBALS['__l10n']['of'] = 'de';
$GLOBALS['__l10n']['next entries'] = 'antaŭaj biletoj';
$GLOBALS['__l10n']['Search'] = 'Serĉi';
$GLOBALS['__l10n']['Your search for <em>%1$s</em> returned no result.'] = 'Via serĉo pri <em>%1$s</em> trovis neniun rezulton.';
$GLOBALS['__l10n']['Your search for <em>%1$s</em> returned <strong>%2$s</strong> result.'] = 'Via serĉo pri <em>%1$s</em> trovis <strong>%2$s</strong> rezultojn.';
$GLOBALS['__l10n']['Your search for <em>%1$s</em> returned <strong>%2$s</strong> results.'] = 'Via serĉo pri <em>%1$s</em> trovis <strong>%2$s</strong> rezultojn.';
$GLOBALS['__l10n']['Home'] = 'Hejmpaĝo';
$GLOBALS['__l10n']['All keywords'] = 'Ĉiuj ŝlosilvortoj';
$GLOBALS['__l10n']['Best of me'] = '';
$GLOBALS['__l10n']['Languages'] = 'Lingvoj';
$GLOBALS['__l10n']['Categories'] = 'Kategorioj';
$GLOBALS['__l10n']['Subcategories'] = 'Subkategorioj';
$GLOBALS['__l10n']['Archives'] = 'Arkivoj';
$GLOBALS['__l10n']['Links'] = 'Ligoj';
$GLOBALS['__l10n']['Subscribe'] = 'Aboni';
$GLOBALS['__l10n']['Entries feed'] = 'Ĉeno de la biletoj';
$GLOBALS['__l10n']['Comments feed'] = 'Ĉeno de la komentoj';
$GLOBALS['__l10n']['This blog\'s comments Atom feed'] = 'La Atom-a ĉeno de tiu blogo komentoj';
$GLOBALS['__l10n']['This category\'s entries Atom feed'] = '';
$GLOBALS['__l10n']['This category\'s comments Atom feed'] = '';
$GLOBALS['__l10n']['This post\'s comments feed'] = '';
$GLOBALS['__l10n']['This post\'s comments Atom feed'] = '';
$GLOBALS['__l10n']['Attachments'] = 'Aldonaĵoj';
$GLOBALS['__l10n']['Permalink'] = 'Permanenta ligilo';
$GLOBALS['__l10n']['Comments'] = 'Komentoj';
$GLOBALS['__l10n']['Your comment'] = 'Via komento';
$GLOBALS['__l10n']['Your comment has been published.'] = 'Via komento estis publikigita';
$GLOBALS['__l10n']['Your comment has been submitted and will be reviewed for publication.'] = 'Via komento estis sendita kaj estos kontrolita antaŭ publikigado.';
$GLOBALS['__l10n']['Add a comment'] = 'Aldoni komenton';
$GLOBALS['__l10n']['Name or nickname'] = 'Nomo';
$GLOBALS['__l10n']['Email address'] = 'Retpoŝtadreso';
$GLOBALS['__l10n']['Website'] = 'Retejo';
$GLOBALS['__l10n']['optional'] = 'opcia';
$GLOBALS['__l10n']['Comment'] = 'Komento';
$GLOBALS['__l10n']['Comments can be formatted using a simple wiki syntax.'] = '';
$GLOBALS['__l10n']['HTML code is displayed as text and web addresses are automatically converted.'] = '';
$GLOBALS['__l10n']['Remember me on this blog'] = 'Memoru min en tiu blogo';
$GLOBALS['__l10n']['preview'] = 'previdi';
$GLOBALS['__l10n']['send'] = 'sendi';
$GLOBALS['__l10n']['They posted on the same topic'] = '';
$GLOBALS['__l10n']['Trackback URL'] = '';
$GLOBALS['__l10n']['You must provide an author name'] = '';
$GLOBALS['__l10n']['You must provide a comment'] = '';
$GLOBALS['__l10n']['Email address is not valid'] = '';
$GLOBALS['__l10n']['Document not found'] = 'Dokumento ne trovebla';
$GLOBALS['__l10n']['The document you are looking for does not exist.'] = 'La dokumento kiun vi serĉas ne ekzistas.';
$GLOBALS['__l10n']['Powered by %s'] = '';
$GLOBALS['__l10n']['Subscribe to'] = '';
$GLOBALS['__l10n']['What is an RSS feed?'] = '';
$GLOBALS['__l10n']['RSS feed is a free blog summary. It provides content (either posts or comments) or summaries of content, together with links to the full versions, and other metadata. The last published items may then be read by your favorite RSS <a href="http://en.wikipedia.org/wiki/Aggregator">aggregator</a>.'] = '';
$GLOBALS['__l10n']['Simply copy the following URL into your aggregator:'] = '';
$GLOBALS['__l10n']['Password needed'] = 'Pasvorto necesa';
$GLOBALS['__l10n']['You must give a password to access this area.'] = 'Vi devas doni pasvorton por vidi tiun paĝon.';
$GLOBALS['__l10n']['Password:'] = 'Pasvorto:';
$GLOBALS['__l10n']['You must provide a valid email address.'] = 'Vi devas doni korektan retpoŝtadreson.';
$GLOBALS['__l10n']['Read'] = 'Legi';
